@@ -1,5 +1,5 @@
 ;;; manifest.scm -- Guix manifest for continuous integration.
-;;; Copyright © 2023 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2023-2024 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of the GNU Shepherd.
 ;;;
@@ -47,11 +47,16 @@ TARGET."
    (append-map (lambda (system)
                  (map (lambda (package)
                         (package->manifest-entry* package system))
-                      (list shepherd
-                            shepherd-from-tarball
-                            guile2.2-shepherd)))
+                      (append
+                       (list shepherd
+                             shepherd-from-tarball
+                             guile2.2-shepherd)
+                       (if (string-suffix? "-linux" system)
+                           (list shepherd/libevent)
+                           '()))))
                '("x86_64-linux"
                  "i686-linux"
+                 "i586-gnu"
                  "aarch64-linux" "armhf-linux"
                  "powerpc64le-linux"))))
 
@@ -60,7 +65,7 @@ TARGET."
    (map (lambda (target)
           (package->manifest-entry* shepherd-from-tarball "x86_64-linux"
                                     #:target target))
-        '(;; "i586-pc-gnu"          ;FIXME: requires Fibers 1.2.0+
+        '("i586-pc-gnu"
           "aarch64-linux-gnu"
           "riscv64-linux-gnu"))))
 
@@ -95,9 +100,13 @@ TARGET."
 (define (system-test->manifest-entry test)
   "Return a manifest entry for @var{test}, a system test."
   (manifest-entry
+    ;; The system test on x86_64 is relatively expensive; run it on x86_64
+    ;; only.
     (name (system-test-name test))
     (version "0")
-    (item test)))
+    (item (with-parameters ((%current-system "x86_64-linux")
+                            (%current-target-system #f))
+            test))))
 
 (define system-tests
   (manifest
