@@ -1,5 +1,5 @@
 # GNU Shepherd --- Test detecting a forked process' termination
-# Copyright © 2016, 2020, 2022, 2023 Ludovic Courtès <ludo@gnu.org>
+# Copyright © 2016, 2020, 2022-2024 Ludovic Courtès <ludo@gnu.org>
 # Copyright © 2018 Carlo Zancanaro <carlo@zancanaro.id.au>
 #
 # This file is part of the GNU Shepherd.
@@ -183,4 +183,15 @@ grep ignoring "$log"
 grep SIGKILL "$log"
 $herd status test3 | grep stopped
 
+# Start 'test'.  Make sure 'unload all' terminates it.
+rm -f "$service_pid"
+$herd enable test
+$herd start test
+child_pid="$(cat "$service_pid")"
+kill -0 "$child_pid"
+$herd unload root all
+$herd status test && false
+kill -0 "$child_pid" && false
+test $($herd status | wc -l) = 2
+
 $herd status
