@@ -67,7 +67,8 @@ cat > "$rconf"<<EOF
 	 '(test)
 	 #:start (lambda _
                    (display "The replacement is starting.\n")
-                   #t)
+                   (fork+exec-command '("$(type -P sleep)" "300")))
+         #:stop (make-kill-destructor)
 	 #:actions (actions
 		    (say-goodbye (lambda _
 				   (call-with-output-file "$stamp"
@@ -95,3 +96,15 @@ $herd stop test
 $herd disable test
 $herd load root "$rconf"
 $herd status test | grep disabled
+
+# Restarting the service from here used to trigger a bug:
+# <https://issues.guix.gnu.org/67839>.
+$herd enable test
+$herd start test
+
+child_pid="$($herd status test | grep Running \
+   | sed '-es/.*Running value is \([0-9]\+\)\./\1/g')"
+kill -0 "$child_pid"
+
+$herd stop test
+if kill -0 "$child_pid"; then false; else true; fi
