@@ -1,5 +1,5 @@
 # GNU Shepherd --- Test transient services.
-# Copyright © 2022 Ludovic Courtès <ludo@gnu.org>
+# Copyright © 2022-2023 Ludovic Courtès <ludo@gnu.org>
 #
 # This file is part of the GNU Shepherd.
 #
@@ -23,11 +23,17 @@ socket="t-socket-$$"
 conf="t-conf-$$"
 log="t-log-$$"
 pid="t-pid-$$"
-service_socket="t-service-socket-$$"
+service_socket_dir="t-service-socket-$$"
+service_socket="$service_socket_dir/socket"
 
 herd="herd -s $socket"
 
-trap "cat $log || true; rm -f $service_socket $socket $conf $log;
+# Create the socket directory with permissions other than those specified in
+# the endpoint.
+mkdir -p "$service_socket_dir"
+chmod 755 "$service_socket_dir"
+
+trap "cat $log || true; rm -r $service_socket_dir $socket $conf $log;
       test -f $pid && kill \`cat $pid\` || true; rm -f $pid" EXIT
 
 cat > "$conf" <<EOF
@@ -56,14 +62,21 @@ cat > "$conf" <<EOF
               (close-port sock)))))))))
 
 (define %endpoints
-  (list (endpoint (make-socket-address AF_UNIX "$service_socket"))))
+  (list (endpoint (make-socket-address AF_UNIX "$service_socket")
+                  #:socket-directory-permissions #o700)))
 
 (register-services
- (make <service>
-   #:provides '(test-systemd-unix)
-   #:start (make-systemd-constructor %command %endpoints)
-   #:stop  (make-systemd-destructor)
-   #:respawn? #t))
+ (list (service
+	 '(test-systemd-unix)
+	 #:start (make-systemd-constructor %command %endpoints)
+	 #:stop  (make-systemd-destructor)
+         #:respawn-delay 0  ;make the test slightly faster
+	 #:respawn? #t)
+       (service
+	 '(test-systemd-unix-eager)
+	 #:start (make-systemd-constructor %command %endpoints
+					   #:lazy-start? #f)
+	 #:stop  (make-systemd-destructor))))
 EOF
 
 rm -f "$pid"
@@ -74,6 +87,11 @@ while ! test -f "$pid" ; do sleep 0.3 ; done
 
 shepherd_pid="`cat $pid`"
 
+file_permissions ()
+{
+    guile -c "(display (number->string (stat:perms (stat \"$1\")) 8))"
+}
+
 converse_with_echo_server ()
 {
     guile -c "(use-modules (ice-9 match) (ice-9 rdelim))
@@ -88,15 +106,39 @@ converse_with_echo_server ()
 
 
 $herd start test-systemd-unix
-$herd status test-systemd-unix | grep started
+$herd status test-systemd-unix | grep running
 test $($herd status | grep '\+' | wc -l) -eq 2
 
+test "$(file_permissions "$service_socket_dir")" = "700"
+test "$(file_permissions "$service_socket")" = "666"
+
 for i in $(seq 1 3)
 do
     converse_with_echo_server \
 	"(make-socket-address AF_UNIX \"$service_socket\")"
+
+    # Wait until the service has been respawned.
+    until $herd status test-systemd-unix | grep running
+    do
+	sleep 0.1
+    done
 done
 
 $herd stop test-systemd-unix
-! converse_with_echo_server \
-  "(make-socket-address AF_UNIX \"$service_socket\")"
+if converse_with_echo_server "(make-socket-address AF_UNIX \"$service_socket\")"
+then false; else true; fi
+
+# Now test the eager systemd-style service.
+$herd start test-systemd-unix-eager
+$herd status test-systemd-unix-eager | grep running
+
+# The process should soon be running, before we've tried to connect to it.
+while ! $herd status test-systemd-unix-eager | grep -E "Running value is [0-9]+"
+do $herd status test-systemd-unix-eager; sleep 0.3; done
+
+child_pid="$($herd status test-systemd-unix-eager | grep Running \
+   | sed '-es/.*Running value is \([0-9]\+\)\./\1/g')"
+kill -0 "$child_pid"
+converse_with_echo_server "(make-socket-address AF_UNIX \"$service_socket\")"
+while ! $herd status test-systemd-unix-eager | grep stopped
+do sleep 0.3; done
